@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -27,6 +27,12 @@ has schema => (
 );
 
 
+has memory => (
+    is        => 'ro',
+    predicate => 'has_memory',
+);
+
+
 has db_attrs => (
     is      => 'ro',
     default => sub { return { RaiseError => 1, AutoCommit => 1 } },
@@ -40,7 +46,7 @@ has dsn => (
 
 sub _build_dsn {
     my ($self) = @_;
-    return 'dbi:SQLite:dbname=' . $self->_database->filename;
+    return 'dbi:SQLite:dbname=' . ( $self->has_memory ? $self->_database : $self->_database->filename );
 }
 
 
@@ -62,7 +68,9 @@ has _database => (
 sub _build__database {
     my ($self) = @_;
 
-    my $filename = File::Temp->new( unlink => 1, suffix => '.db', EXLOCK => 0 );
+    my $filename = $self->has_memory
+        ? ':memory:'
+        : File::Temp->new( unlink => 1, suffix => '.db', EXLOCK => 0 );
 
     if ( $self->has_database ) {
         copy( $self->database, $filename )
@@ -101,8 +109,10 @@ sub _build__database {
 
 sub BUILD {
     my ( $self, $args ) = @_;
-    die 'Schema and database may not be used at the same time.'
-        if $self->has_database and $self->has_schema;
+    die 'The schema, database and memory arguments may not be used together.'
+        if ( $self->has_database and $self->has_schema )
+            or ( $self->has_database and $self->has_memory )
+            or ( $self->has_schema and $self->has_memory );
 }
 
 1;
@@ -119,7 +129,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0300
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -132,6 +142,12 @@ version 0.0300
   # Fiddle with the test database...
   $dbh->disconnect;
 
+  # Use an in-memory database:
+  $sqlite = Test::SQLite->new(memory => 1);
+  $dbh = $sqlite->dbh;
+  # Fiddle with the test database...
+  $dbh->disconnect;
+
   # Copy a database file to the test db:
   $sqlite = Test::SQLite->new(database => '/some/where/production.db');
   $dbh = $sqlite->dbh;
@@ -152,8 +168,7 @@ version 0.0300
 =head1 DESCRIPTION
 
 C<Test::SQLite> is loosely inspired by L<Test::PostgreSQL> and
-L<Test::mysqld>, and creates a temporary db to use in tests.  Unlike
-those modules, it is limited to setup/teardown of the test db.
+L<Test::mysqld>, and creates a temporary db to use in tests.
 
 This module will also return the database B<dbh> handle, B<dsn>
 connection string, and B<db_attrs> connection attributes.
@@ -166,7 +181,8 @@ The database to copy.
 
 =head2 has_database
 
-Boolean indicating that a database file was provided to the constructor.
+Boolean indicating that a B<database> file was provided to the
+constructor.
 
 =head2 schema
 
@@ -176,7 +192,16 @@ The SQL schema with which to create a test database.
 
 =head2 has_schema
 
-Boolean indicating that a schema file was provided to the constructor.
+Boolean indicating that a B<schema> file was provided to the
+constructor.
+
+=head2 memory
+
+Create a test database in memory.
+
+=head2 has_memory
+
+Boolean indicating that B<memory> was provided to the constructor.
 
 =head2 db_attrs
 
@@ -201,16 +226,15 @@ Create a new C<Test::SQLite> object.
 
 =head2 BUILD
 
-Ensure that we are not given both a B<database> and B<schema>.
-
-=head1 TO DO
-
-Use in memory storage.
+Ensure that we are only given one of B<database>, B<schema> or
+B<memory> in the constructor.
 
 =head1 SEE ALSO
 
 The F<t/01-methods.t> file in this distribution.
 
+The F<eg/dbic.t> example test in this distribution.
+
 L<DBI>
 
 L<File::Copy>
